@@ -2,6 +2,7 @@ package Test::BrewBuild::Dispatch;
 use strict;
 use warnings;
 
+use Capture::Tiny qw(:all);
 use Carp qw(croak);
 use Config::Tiny;
 use Cwd qw(getcwd);
@@ -12,7 +13,7 @@ use Storable;
 use Test::BrewBuild;
 use Test::BrewBuild::Git;
 
-our $VERSION = '2.13';
+our $VERSION = '2.14';
 
 $| = 1;
 
@@ -39,6 +40,57 @@ sub new {
 
     return $self;
 }
+sub auto {
+    my ($self, %params) = @_;
+
+    my $log = $log->child('auto');
+
+    $log->_5("commencing auto run dispatch sequence");
+
+    my $git = Test::BrewBuild::Git->new;
+    my $sleep = defined $self->{auto_sleep} ? $self->{auto_sleep} : 60;
+
+    my $runs = $params{auto};
+    my $run_count = 1;
+
+    $log->_7("$runs auto runs planned");
+
+    my $err = capture_stderr {
+            $git->status;
+    };
+
+    if ($err =~ /fatal: Not a git repository/){
+        $log->_5("auto failed due to not being in a git repo");
+        croak "not in a Git repository... can't continue.";
+    }
+
+    while (1){
+        my $status = $git->status(repo => $params{repo});
+        my $local_sum = $git->revision(repo => $params{repo});
+        my $remote_sum = $git->revision(remote => 1, repo => $params{repo});
+
+        if ($status || $local_sum eq $remote_sum){
+            $log->_6("local and remote commit sums match. Nothing to do");
+            sleep $sleep;
+            next;
+        }
+
+        $log->_6("commit sums don't match... commencing run $run_count of $runs");
+
+        my $results = $self->dispatch(%params);
+
+        $log->_6(
+            "auto run complete. Sleeping, then restarting if more runs required"
+        );
+
+        print $results;
+
+        exit() if $run_count >= $runs;
+        $run_count++;
+
+        sleep $sleep;
+    }
+}
 sub dispatch {
     my ($self, %params) = @_;
 
@@ -141,6 +193,7 @@ sub _config {
         }
         $self->{repo} = $conf->{repo} if $conf->{repo};
         $self->{cmd} = $conf->{cmd} if $conf->{cmd};
+        $self->{auto_sleep} = $conf->{cmd} if defined $conf->{auto_sleep};
     }
 }
 sub _fork {
@@ -319,6 +372,16 @@ C<debug> optional, set to a level between 0 and 7.
 See L<Test::BrewBuild::Tester> for more details on the testers that the
 dispatcher dispatches to.
 
+=head2 auto(%params)
+
+This function will spin off a continuous run of C<dispatch()> runs, based on
+whether the commit revision checksum locally is different than that from the
+remote. It takes all of the same parameters as C<dispatch()>.
+
+There is also a configuration file directive in the C<[Dispatch]> section,
+C<auto_sleep>, which dictates how many seconds to sleep in between each run. The
+default is C<60>, or one minute.
+
 =head1 AUTHOR
 
 Steve Bertrand, C<< <steveb at cpan.org> >>
