@@ -7,7 +7,7 @@ use Carp qw(croak);
 use Logging::Simple;
 use LWP::Simple qw(head);
 
-our $VERSION = '2.13';
+our $VERSION = '2.14';
 
 my $log;
 
@@ -92,6 +92,55 @@ sub pull {
     my $output = `"$git" pull`;
     return $output;
 }
+sub revision {
+    my ($self, %args) = @_;
+
+    my $remote = $args{remote};
+
+    my $git = $self->git;
+
+    $log->child('revision')->_6("initiating git revision");
+
+    my $csum;
+
+    if (! $remote) {
+        $csum = `$git rev-parse HEAD`;
+    }
+    else {
+        $csum = `$git rev-parse origin/master`;
+    }
+
+    chomp $csum;
+    return $csum;
+}
+sub status {
+    my ($self) = @_;
+
+    my $git = $self->git;
+
+    my $status = `$git status`;
+
+    if ($status =~ /Your branch is ahead/){
+        return 0;
+    }
+    return 1;
+}
+sub _separate_url {
+    # this method is actually not needed. Was going to be used if we used the
+    # github API to fetch stuff...
+    # eg:   https://api.github.com/repos/$user/$repo/commits
+
+    my ($self, $repo) = @_;
+
+    if (! defined $repo){
+        $repo = $self->link;
+    }
+
+    my ($user, $repo_name) = (split /\//, $repo)[-2, -1];
+
+    return ($user, $repo_name);
+}
+
 1;
 
 =head1 NAME
@@ -150,6 +199,31 @@ Clones the repo into the current working directory.
 
 While in a repository directory, pull down any updates.
 
+=head2 revision(remote => $bool, repo => $github_url)
+
+Returns the current commit SHA1 for a repo, with ability to get the local commit
+or remote commit SHA1 sum.
+
+Parameters:
+
+All parameters are passed in as a hash.
+
+    repo
+
+Optional, string. The Github url to the repo. If not sent in, we will attempt
+to get this information from the current working directory.
+
+    remote
+
+Optional, bool. If sent in, we'll fetch the current commit's SHA1 sum from
+Github itself, else we'll get the sum from the most recent local, unpushed
+commit.
+
+=head2 status
+
+Returns true of the repo we're working on is behind or equal to the remote
+regarding commits, and false if we're ahead.
+
 =head1 AUTHOR
 
 Steve Bertrand, C<< <steveb at cpan.org> >>
